@@ -15,6 +15,10 @@ def adoc2xml(manuscript_dir='/home/hobs/code/tangibleai/nlpia-manuscript/manuscr
     return results
 
 
+def parse_xml_file(xmlpath):
+    return xmltodict.parse(open(xmlpath).read())
+
+
 def parse_xml_files(xmlpath, ext='.xml'):
     """ Read an xml file or directory of files (non-recursively) and return a nested dict
 
@@ -22,12 +26,12 @@ def parse_xml_files(xmlpath, ext='.xml'):
     """
     bookdict = {}
     xmlpath = Path(xmlpath)
-    if dirpath.is_dir():
+    if xmlpath.is_dir():
         filepaths = sorted(xmlpath.listdir())
     else:
-        filepaths = [dirpath]
-    for f in filepaths:
-        filepath = Path(dirpath) / f
+        filepaths = [xmlpath]
+    for filepath in filepaths:
+        # filepath = Path(dirpath) / filepath
         if not str(filepath).endswith(ext):
             continue
         # print(filepath)
@@ -36,9 +40,9 @@ def parse_xml_files(xmlpath, ext='.xml'):
         try:
             xmldict = xmltodict.parse(xmlstring)
         except Exception as e:
-            log.warning(f'**ParseError** -- Unable to parse "{f}":')
+            log.warning(f'**ParseError** -- Unable to parse "{filepath}":')
             log.warning(f'    {e}')
-        bookdict[f] = xmldict
+        bookdict[filepath] = xmldict
     return bookdict
 
 
